Struct crc32fast::Hasher [−][src]
pub struct Hasher { /* fields omitted */ }Expand description
Represents an in-progress CRC32 computation.
Implementations
Create a new Hasher.
This will perform a CPU feature detection at runtime to select the most optimal implementation for the current processor architecture.
Create a new Hasher with an initial CRC32 state.
This works just like Hasher::new, except that it allows for an initial
CRC32 state to be passed in.
Create a new Hasher with an initial CRC32 state.
As new_with_initial, but also accepts a length (in bytes). The
resulting object can then be used with combine to compute crc(a || b) from crc(a), crc(b), and len(b).